"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tagProcessor = tagProcessor;
var _logger = require("../../utils/logger");
/* eslint-disable dot-notation */

function getTagsString(tags, editionTags) {
  return tags && tags !== '' ? `${tags} and not (${editionTags})` : `not (${editionTags})`;
}
function getEdition(edition) {
  if (edition.startsWith('<=')) {
    return ['<=', edition.slice(2)];
  } else if (edition.startsWith('>=')) {
    return ['>=', edition.slice(2)];
  } else if (edition.startsWith('<')) {
    return ['<', edition.slice(1)];
  } else if (edition.startsWith('>')) {
    return ['>', edition.slice(1)];
  }
  return [null, edition];
}
function editionPreprocessing(editionOrder, selectedEdition) {
  const [operator, editionToBeSearched] = getEdition(selectedEdition.toLowerCase());
  const index = editionOrder.findIndex(edition => edition.toLowerCase() === editionToBeSearched);
  if (index !== -1) {
    let resultArray;
    if (operator === '<=') {
      resultArray = editionOrder.slice(index + 1);
    } else if (operator === '>=') {
      resultArray = editionOrder.slice(0, index);
    } else if (operator === '<') {
      resultArray = editionOrder.slice(index);
    } else if (operator === '>') {
      resultArray = editionOrder.slice(0, index + 1);
    } else {
      resultArray = editionOrder.filter((_, order) => order !== index);
    }
    return resultArray;
  }
  _logger.Logger.log(_logger.Logger.INFO_TYPE, `No matching editions ${selectedEdition} found. Running with default edition`);
  return [];
}
function buildEditionTags(editionArgs, operator) {
  return editionArgs.map(edition => `@edition_${edition}`).join(` ${operator} `);
}
function tagProcessor(userArgsObject, editionOrder) {
  let tagArgs = userArgsObject['tags'];
  const edition = userArgsObject['edition'] || null;
  if (edition !== null) {
    let editionsArray = edition.split(',');
    if (editionsArray.length === 1) {
      const editionArgs = editionPreprocessing(editionOrder, edition);
      if (editionArgs && editionArgs.length > 0) {
        const editionTags = buildEditionTags(editionArgs, 'or');
        tagArgs = `${getTagsString(tagArgs, editionTags)}`;
      }
    } else {
      // More than one edition given
      const filteredEditions = editionOrder.filter(edition => !editionsArray.includes(edition));
      const editionTags = buildEditionTags(filteredEditions, 'or');
      tagArgs = `${getTagsString(tagArgs, editionTags)}`;
    }
  }
  return tagArgs;
}